@@ -161,9 +161,14 @@ class JVCProjector:
             "B2A2": "NX7",
             "B2A3": "NX5",
             "B5B1": "NP5",
+            "XHR1": "X570R",
+            "XHR3": "X770R||X970R",
             "XHP1": "X5000",
             "XHP2": "XC6890",
             "XHP3": "X7000||X9000",
+            "XHK1": "X500R",
+            "XHK2": "RS4910",
+            "XHK3": "X700R||X900R",
         }
         model_res = self._replace_headers(res).decode()
         self.logger.debug(model_res)
